@@ -1,5 +1,6 @@
 from enum import Enum
 from io import StringIO
+import copy
 
 class GemTextLineType(Enum):
     Text = 1
@@ -48,10 +49,10 @@ class GemText:
     def __init__(self):
         pass
 
-    def copy(self):
+    def deepcopy(self):
         result = GemText()
-        result.firstLevel1Heading = self.firstLevel1Heading
-        result.lines = self.lines.copy()
+        result.firstLevel1Heading = copy.copy(self.firstLevel1Heading)
+        result.lines = copy.deepcopy(self.lines)
         return result
 
     def string(self):
